@@ -1,7 +1,7 @@
 /*
  *  datepicker.cpp  -  date chooser widget
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2021-2022 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2021-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -23,8 +23,27 @@
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include <QLocale>
+#include <QWheelEvent>
 #include <QApplication>
 
+class DPToolButton : public QToolButton
+{
+    Q_OBJECT
+public:
+    DPToolButton(QWidget* parent) : QToolButton(parent) {}
+    QSize sizeHint() const override
+    {
+        QSize s = QToolButton::sizeHint();
+        return QSize(s.width() * 4 / 5, s.height());
+    }
+    QSize minimumSizeHint() const override
+    {
+        QSize s = QToolButton::minimumSizeHint();
+        return QSize(s.width() * 4 / 5, s.height());
+    }
+};
+
+
 DatePicker::DatePicker(QWidget* parent)
     : QWidget(parent)
 {
@@ -46,14 +65,16 @@ DatePicker::DatePicker(QWidget* parent)
     hlayout->setContentsMargins(0, 0, 0, 0);
     topLayout->addLayout(hlayout);
 
-    QToolButton* leftYear   = createArrowButton(QStringLiteral("arrow-left-double"));
-    QToolButton* leftMonth  = createArrowButton(QStringLiteral("arrow-left"));
-    QToolButton* rightMonth = createArrowButton(QStringLiteral("arrow-right"));
-    QToolButton* rightYear  = createArrowButton(QStringLiteral("arrow-right-double"));
+    DPToolButton* leftYear   = createArrowButton(QStringLiteral("arrow-left-double"));
+    DPToolButton* leftMonth  = createArrowButton(QStringLiteral("arrow-left"));
+    DPToolButton* rightMonth = createArrowButton(QStringLiteral("arrow-right"));
+    DPToolButton* rightYear  = createArrowButton(QStringLiteral("arrow-right-double"));
+    DPToolButton* today      = createArrowButton(QStringLiteral("show-today"));
     mPrevYear  = leftYear;
     mPrevMonth = leftMonth;
     mNextYear  = rightYear;
     mNextMonth = rightMonth;
+    mToday     = today;
     if (QApplication::isRightToLeft())
     {
         mPrevYear  = rightYear;
@@ -65,10 +86,12 @@ DatePicker::DatePicker(QWidget* parent)
     mPrevMonth->setToolTip(i18nc("@info:tooltip", "Show the previous month"));
     mNextYear->setToolTip(i18nc("@info:tooltip", "Show the next year"));
     mNextMonth->setToolTip(i18nc("@info:tooltip", "Show the next month"));
+    mToday->setToolTip(i18nc("@info:tooltip", "Show today"));
     connect(mPrevYear, &QToolButton::clicked, this, &DatePicker::prevYearClicked);
     connect(mPrevMonth, &QToolButton::clicked, this, &DatePicker::prevMonthClicked);
     connect(mNextYear, &QToolButton::clicked, this, &DatePicker::nextYearClicked);
     connect(mNextMonth, &QToolButton::clicked, this, &DatePicker::nextMonthClicked);
+    connect(mToday, &QToolButton::clicked, this, &DatePicker::todayClicked);
 
     const QDate currentDate = KADateTime::currentDateTime(Preferences::timeSpec()).date();
     mMonthYear = new QLabel(this);
@@ -84,6 +107,8 @@ DatePicker::DatePicker(QWidget* parent)
     }
     mMonthYear->setMinimumWidth(maxWidth);
 
+    if (QApplication::isRightToLeft())
+        hlayout->addWidget(mToday);
     hlayout->addWidget(mPrevYear);
     hlayout->addWidget(mPrevMonth);
     hlayout->addStretch();
@@ -91,6 +116,8 @@ DatePicker::DatePicker(QWidget* parent)
     hlayout->addStretch();
     hlayout->addWidget(mNextMonth);
     hlayout->addWidget(mNextYear);
+    if (!QApplication::isRightToLeft())
+        hlayout->addWidget(mToday);
 
     // Set up the day name headings.
     // These start at the user's start day of the week.
@@ -119,6 +146,7 @@ DatePicker::DatePicker(QWidget* parent)
     mDayMatrix = new DayMatrix(widget);
     mDayMatrix->setWhatsThis(whatsThis);
     vlayout->addWidget(mDayMatrix);
+    mDayMatrix->installEventFilter(this);
     connect(mDayMatrix, &DayMatrix::selected, this, &DatePicker::datesSelected);
     connect(mDayMatrix, &DayMatrix::newAlarm, this, &DatePicker::slotNewAlarm);
     connect(mDayMatrix, &DayMatrix::newAlarmFromTemplate, this, &DatePicker::slotNewAlarmFromTemplate);
@@ -155,6 +183,27 @@ void DatePicker::showEvent(QShowEvent* e)
     QWidget::showEvent(e);
 }
 
+/******************************************************************************
+* Receives events destined for the day matrix.
+*/
+bool DatePicker::eventFilter(QObject* obj, QEvent* e)
+{
+    if (obj == mDayMatrix)
+    {
+        if (e->type() == QEvent::Wheel)
+        {
+            auto* we = (QWheelEvent*)e;
+            if (we->angleDelta().y() > 0)
+                prevMonthClicked();
+            else
+                nextMonthClicked();
+            return true;
+        }
+        return false;
+    }
+    return QWidget::eventFilter(obj, e);
+}
+
 /******************************************************************************
 * Called when the previous year arrow button has been clicked.
 */
@@ -203,6 +252,21 @@ void DatePicker::nextMonthClicked()
     updateDisplay();
 }
 
+/******************************************************************************
+* Called when the today button has been clicked.
+*/
+void DatePicker::todayClicked()
+{
+    const QDate currentDate = KADateTime::currentDateTime(Preferences::timeSpec()).date();
+    const QDate monthToShow(currentDate.year(), currentDate.month(), 1);
+    if (monthToShow != mMonthShown)
+    {
+        mMonthShown = monthToShow;
+        newMonthShown();
+        updateDisplay();
+    }
+}
+
 /******************************************************************************
 * Called at midnight. If the month has changed, update the view.
 */
@@ -269,13 +333,15 @@ void DatePicker::updateDisplay()
 /******************************************************************************
 * Create an arrow button for moving backwards or forwards.
 */
-QToolButton* DatePicker::createArrowButton(const QString& iconId)
+DPToolButton* DatePicker::createArrowButton(const QString& iconId)
 {
-    QToolButton* button = new QToolButton(this);
+    DPToolButton* button = new DPToolButton(this);
     button->setIcon(QIcon::fromTheme(iconId));
     button->setToolButtonStyle(Qt::ToolButtonIconOnly);
     button->setAutoRaise(true);
     return button;
 }
 
+#include "datepicker.moc"
+
 // vim: et sw=4:
