@@ -28,6 +28,7 @@
 #include "akonadiplugin/akonadiplugin.h"
 #include "kalarm_debug.h"
 
+#include <kcalendarcore_version.h>
 #include <KCalendarCore/Event>
 #include <KCalendarCore/ICalFormat>
 #include <KCalendarCore/Person>
@@ -36,7 +37,6 @@
 using namespace KCalendarCore;
 #include <KIdentityManagement/IdentityManager>
 #include <KIdentityManagement/Identity>
-#include <KHolidays/HolidayRegion>
 
 #include <KConfigGroup>
 #include <KSharedConfig>
@@ -1014,7 +1014,9 @@ bool exportAlarms(const QVector<KAEvent>& events, QWidget* parent)
         }
         delete tempFile;
     }
+#if KCALENDARCORE_VERSION < QT_VERSION_CHECK(5, 240, 0)
     calendar->close();
+#endif
     return success;
 }
 
