@@ -378,14 +378,22 @@ bool SpinBox2p::eventFilter(QObject* obj, QEvent* e)
             case QEvent::HoverEnter:
             {
                 auto* he = (QHoverEvent*)e;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+                QApplication::postEvent(mSpinbox2, new QHoverEvent(e->type(), QPoint(1, he->position().toPoint().y()), he->oldPos()));
+#else
                 QApplication::postEvent(mSpinbox2, new QHoverEvent(e->type(), QPoint(1, he->pos().y()), he->oldPos()));
+#endif
                 updateButtons = true;
                 break;
             }
             case QEvent::HoverLeave:
             {
                 auto* he = (QHoverEvent*)e;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+                QApplication::postEvent(mSpinbox2, new QHoverEvent(e->type(), he->position().toPoint(), QPoint(1, he->oldPos().y())));
+#else
                 QApplication::postEvent(mSpinbox2, new QHoverEvent(e->type(), he->pos(), QPoint(1, he->oldPos().y())));
+#endif
                 updateButtons = true;
                 break;
             }
@@ -491,7 +499,7 @@ mSpinbox2->setAutoFillBackground(true);
 void SpinBox2p::getMetrics() const
 {
     QStyleOptionSpinBox option;
-    mSpinbox->initStyleOption(option);
+    mSpinbox->initStyleOption(&option);
     const QRect editRect = spinBoxEditFieldRect(mSpinbox);
     {
         // Check whether both mSpinbox spin buttons are on the same side of the control,
@@ -508,7 +516,7 @@ void SpinBox2p::getMetrics() const
     const QRect buttons2Rect = spinBoxButtonsRect(mSpinbox2, true);
     const QRect buttons2DrawRect = spinBoxButtonsRect(mSpinbox2, false);
     QStyle* udStyle = mSpinbox2->style();
-    mSpinbox2->initStyleOption(option);
+    mSpinbox2->initStyleOption(&option);
     const QRect frame2Rect = udStyle->subControlRect(QStyle::CC_SpinBox, &option, QStyle::SC_SpinBoxFrame);
     wFrameWidth = udStyle->pixelMetric(QStyle::PM_SpinBoxFrameWidth, &option);
     wBorderWidth = mRightToLeft ? buttons2Rect.left() : mSpinbox2->width() - buttons2Rect.right() - 1;
@@ -692,7 +700,7 @@ void SpinMirror::setFrameImage()
         // frame and edit field.
         QStyle* mainStyle = mMainSpinbox->style();
         QStyleOptionSpinBox option;
-        mMainSpinbox->initStyleOption(option);
+        mMainSpinbox->initStyleOption(&option);
         const int frameWidth = mainStyle->pixelMetric(QStyle::PM_SpinBoxFrameWidth, &option);  // offset to edit field
         const int editOffsetY = frameWidth;
         const int editOffsetX = 2;   // offset into edit field
@@ -843,7 +851,11 @@ bool SpinMirror::event(QEvent* e)
             Q_FALLTHROUGH();
         case QEvent::HoverEnter:
             he = (QHoverEvent*)e;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            QApplication::postEvent(mMainSpinbox, new QHoverEvent(e->type(), he->position().toPoint(), he->oldPos()));
+#else
             QApplication::postEvent(mMainSpinbox, new QHoverEvent(e->type(), he->pos(), he->oldPos()));
+#endif
             break;
         case QEvent::HoverMove:
             he = (QHoverEvent*)e;
@@ -857,7 +869,11 @@ bool SpinMirror::event(QEvent* e)
 
     if (he)
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        QApplication::postEvent(mSpinbox, new QHoverEvent(e->type(), spinboxPoint(he->position()), spinboxPoint(he->oldPosF())));
+#else
         QApplication::postEvent(mSpinbox, new QHoverEvent(e->type(), spinboxPoint(he->posF()), spinboxPoint(he->oldPosF())));
+#endif
         setButtonsImage();
     }
 
@@ -894,7 +910,7 @@ bool isBaseBackground(const QStyle* style)
 QRect spinBoxEditFieldRect(const SpinBox* w)
 {
     QStyleOptionSpinBox option;
-    w->initStyleOption(option);
+    w->initStyleOption(&option);
     QRect r = w->style()->subControlRect(QStyle::CC_SpinBox, &option, QStyle::SC_SpinBoxEditField);
     return r;
 }
@@ -902,7 +918,7 @@ QRect spinBoxEditFieldRect(const SpinBox* w)
 QRect spinBoxButtonsRect(const SpinBox* w, bool includeBorders)
 {
     QStyleOptionSpinBox option;
-    w->initStyleOption(option);
+    w->initStyleOption(&option);
     QRect r = w->style()->subControlRect(QStyle::CC_SpinBox, &option, QStyle::SC_SpinBoxUp)
             | w->style()->subControlRect(QStyle::CC_SpinBox, &option, QStyle::SC_SpinBoxDown);
     if (w->style()->inherits("PlastikStyle"))
