@@ -19,11 +19,11 @@
 #include "lib/messagebox.h"
 #include "lib/pushbutton.h"
 #include "lib/synchtimer.h"
+#include "screensaver.h" // DBUS-generated
 #include "kalarm_debug.h"
 
-#include <kpimtextedit/kpimtextedit-texttospeech.h>
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
-#include <KPIMTextEdit/TextToSpeech>
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+#include <TextEditTextToSpeech/TextToSpeech>
 #endif
 
 #include <KLocalizedString>
@@ -48,6 +48,12 @@
 
 using namespace KAlarmCal;
 
+namespace
+{
+const char FDO_SCREENSAVER_SERVICE[] = "org.freedesktop.ScreenSaver";
+const char FDO_SCREENSAVER_PATH[]    = "/org/freedesktop/ScreenSaver";
+}
+
 // Error message bit masks
 enum
 {
@@ -682,7 +688,7 @@ bool MessageDisplayHelper::readPropertyValues(const KConfigGroup& config)
     mDefaultDeferMinutes = config.readEntry("DeferMins", 0);
     mNoDefer             = config.readEntry("NoDefer", false);
     mNoPostAction        = config.readEntry("NoPostAction", true);
-    mEmailId             = config.readEntry("EmailId", QVariant(QVariant::LongLong)).toLongLong();
+    mEmailId             = config.readEntry("EmailId", KAEvent::EmailId(0));
     mCommandError        = KAEvent::CmdErrType(config.readEntry("CmdErr", static_cast<int>(KAEvent::CMD_NO_ERROR)));
     mDontShowAgain       = config.readEntry("DontShowAgain", QString());
     mShowEdit            = false;
@@ -835,8 +841,8 @@ void MessageDisplayHelper::playAudio()
 */
 void MessageDisplayHelper::slotSpeak()
 {
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
-    KPIMTextEdit::TextToSpeech* tts = KPIMTextEdit::TextToSpeech::self();
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+    TextEditTextToSpeech::TextToSpeech* tts = TextEditTextToSpeech::TextToSpeech::self();
     if (!tts->isReady())
     {
         KAMessageBox::detailedError(MainWindow::mainMainWindow(), i18nc("@info", "Unable to speak message"), i18nc("@info", "Text-to-speech subsystem is not available"));
@@ -911,6 +917,26 @@ void MessageDisplayHelper::stopAudio()
         mAudioPlayer->stop();
 }
 
+/******************************************************************************
+* Ensure that the screen wakes from sleep, in case the window manager doesn't
+* do this when the window is displayed.
+*/
+void MessageDisplayHelper::wakeScreen()
+{
+    qCDebug(KALARM_LOG) << "MessageDisplayHelper::wakeScreen";
+    // Note that this freedesktop D-Bus call to wake the screen may not work on
+    // all systems. It is known to work on X11.
+    QDBusConnection conn = QDBusConnection::sessionBus();
+    if (conn.interface()->isServiceRegistered(QString::fromLatin1(FDO_SCREENSAVER_SERVICE)))
+    {
+        OrgFreedesktopScreenSaverInterface ssiface(
+                QString::fromLatin1(FDO_SCREENSAVER_SERVICE),
+                QString::fromLatin1(FDO_SCREENSAVER_PATH),
+                conn);
+        ssiface.SimulateUserActivity();
+    }
+}
+
 /******************************************************************************
 * Called when the audio file is ready to start playing.
 */
