@@ -12,8 +12,6 @@
 #include "recurrenceedit.h"
 #include "recurrenceedit_p.h"
 
-#include "alarmtimewidget.h"
-#include "kalarmapp.h"
 #include "preferences.h"
 #include "repetitionbutton.h"
 #include "lib/buttongroup.h"
