@@ -1,7 +1,7 @@
 /*
  *  fileresourcesettings.h  -  settings for calendar resource accessed via file system
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2020,2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2020-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -9,9 +9,8 @@
 #pragma once
 
 #include "fileresource.h"
-
-#include <KAlarmCal/KACalendar>
-#include <KAlarmCal/KAEvent>
+#include "kalarmcalendar/kacalendar.h"
+#include "kalarmcalendar/kaevent.h"
 
 #include <QUrl>
 #include <QColor>
@@ -38,7 +37,7 @@ public:
         KAEvent::CmdErrType error;
     };
 
-    FileResourceSettings()  {}
+    FileResourceSettings() = default;
 
     /** Initialises the settings from a config file section. */
     FileResourceSettings(KConfig* config, const QString& resourceGroup);
@@ -51,6 +50,9 @@ public:
                          CalEvent::Types enabledTypes, CalEvent::Types standardTypes,
                          bool readOnly);
 
+    FileResourceSettings(const FileResourceSettings&) = delete;
+    FileResourceSettings& operator=(const FileResourceSettings&) = delete;
+
     ~FileResourceSettings();
 
     /** Reads the settings from the resource's config file section.
@@ -317,5 +319,4 @@ private:
     bool              mUpdateFormat {false}; // request to update the calendar file to the current KAlarm format
 };
 
-
 // vim: et sw=4:
