@@ -11,9 +11,7 @@
 #include "resourcedatamodelbase.h"
 #include "resourceselectdialog.h"
 
-#include "preferences.h"
 #include "lib/autoqpointer.h"
-#include "lib/messagebox.h"
 #include "kalarm_debug.h"
 
 #include <KLocalizedString>
