@@ -1,7 +1,7 @@
 /*
  *  traywindow.cpp  -  the KDE system tray applet
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2002-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2002-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -19,10 +19,9 @@
 #include "resources/datamodel.h"
 #include "resources/eventmodel.h"
 #include "lib/synchtimer.h"
+#include "kalarmcalendar/alarmtext.h"
 #include "kalarm_debug.h"
 
-#include <KAlarmCal/AlarmText>
-
 #include <KLocalizedString>
 #include <KStandardAction>
 #include <KAboutData>
@@ -324,7 +323,6 @@ void TrayWindow::updateIcon()
 */
 QString TrayWindow::tooltipAlarmText() const
 {
-    KAEvent event;
     const QString& prefix = Preferences::tooltipTimeToPrefix();
     int maxCount = Preferences::tooltipAlarmCount();
     const KADateTime now = KADateTime::currentLocalDateTime();
