@@ -12,11 +12,9 @@
 #include "functions.h"
 #include "kalarmapp.h"
 #include "mainwindow.h"
-#include "preferences.h"
 #include "resourcescalendar.h"
 #include "lib/messagebox.h"
 #include "kalarmcalendar/kaevent.h"
-#include "kalarm_debug.h"
 
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -145,7 +143,7 @@ void WakeFromSuspendDlg::useWakeClicked()
     const KADateTime dt = event.mainDateTime().kDateTime();
     if (dt.isDateOnly())
     {
-        KAMessageBox::sorry(this, i18nc("@info", "Cannot schedule wakeup time for a date-only alarm"));
+        KAMessageBox::error(this, i18nc("@info", "Cannot schedule wakeup time for a date-only alarm"));
         return;
     }
     if (KAMessageBox::warningContinueCancel(this,
